@@ -8,10 +8,12 @@ import pandas as pd
 from pythonjsonlogger.jsonlogger import JsonFormatter
 import boto3
 from dotenv import load_dotenv
+from importlib.metadata import version
 
 from SharedData.SharedDataAWSKinesis import KinesisLogStreamHandler
 
 
+
 load_dotenv()  # take environment variables from .env.
 
 if not 'DATABASE_FOLDER' in os.environ:    
@@ -88,7 +90,10 @@ class Logger:
         self.log.addHandler(kinesishandler)
         #assign static variable log to be used by modules
         Logger.log = self.log
-        Logger.log.debug('Logger initialized!')
+        try:
+            Logger.log.debug('Logger initialized shareddata version %s!' % version('SharedData'))
+        except:
+            Logger.log.debug('Logger initialized shareddata!')
         
     def readLogs(self):    
         logsdir = Path(os.environ['LOG_PATH']).parents[0]
