@@ -17,16 +17,16 @@ class KinesisLogStreamHandler(logging.StreamHandler):
         # By default, logging.StreamHandler uses sys.stderr if stream parameter is not specified
         logging.StreamHandler.__init__(self)
         
-        self.__datastream = None
-        self.__stream_buffer = []
+        self.datastream = None
+        self.stream_buffer = []
 
         try:
             session = boto3.Session(profile_name=os.environ['LOG_PROFILENAME'])
-            self.__datastream = session.client('kinesis')
+            self.datastream = session.client('kinesis')
         except Exception:
             print('Kinesis client initialization failed.')
 
-        self.__stream_name = os.environ['LOG_STREAMNAME']
+        self.stream_name = os.environ['LOG_STREAMNAME']
         
     def emit(self, record):
         try:
@@ -46,8 +46,8 @@ class KinesisLogStreamHandler(logging.StreamHandler):
                     'file_name': record.filename,                
                 }   
 
-            if self.__datastream:
-                self.__stream_buffer.append({
+            if self.datastream:
+                self.stream_buffer.append({
                     'Data': str(msg).encode(encoding="UTF-8", errors="strict"),
                     'PartitionKey' : user,
                 })
@@ -63,17 +63,17 @@ class KinesisLogStreamHandler(logging.StreamHandler):
     def flush(self):
         self.acquire()
         try:
-            if self.__datastream and self.__stream_buffer:
-                self.__datastream.put_records(
-                    StreamName=self.__stream_name,
-                    Records=self.__stream_buffer                   
+            if self.datastream and self.stream_buffer:
+                self.datastream.put_records(
+                    StreamName=self.stream_name,
+                    Records=self.stream_buffer                   
                 )
 
-                self.__stream_buffer.clear()
+                self.stream_buffer.clear()
         except Exception as e:
             print("An error occurred during flush operation.")
             print(f"Exception: {e}")
-            print(f"Stream buffer: {self.__stream_buffer}")
+            print(f"Stream buffer: {self.stream_buffer}")
         finally:
             if self.stream and hasattr(self.stream, "flush"):
                 self.stream.flush()
@@ -167,36 +167,36 @@ class KinesisLogStreamConsumer():
 class KinesisStreamProducer():
     def __init__(self,stream_name, profile_name):
 
-        self.__stream_name = stream_name
-        self.__profile_name = profile_name
-        self.__datastream = None
-        self.__stream_buffer = []
+        self.stream_name = stream_name
+        self.profile_name = profile_name
+        self.datastream = None
+        self.stream_buffer = []
         try:
-            session = boto3.Session(profile_name=self.__profile_name)
-            self.__datastream = session.client('kinesis')
+            session = boto3.Session(profile_name=self.profile_name)
+            self.datastream = session.client('kinesis')
         except Exception:
             print('Kinesis client initialization failed.')
 
     def produce(self, record, partitionkey):                
-        self.__stream_buffer.append({
+        self.stream_buffer.append({
             'Data': str(record).encode(encoding="UTF-8", errors="strict"),
             'PartitionKey' : partitionkey,
         })
-        self.__datastream.put_records(
-                    StreamName=self.__stream_name,
-                    Records=self.__stream_buffer                   
+        self.datastream.put_records(
+                    StreamName=self.stream_name,
+                    Records=self.stream_buffer                   
                 )
-        self.__stream_buffer = []
+        self.stream_buffer = []
 
 class KinesisStreamConsumer():
     def __init__(self,stream_name, profile_name):
-        self.__stream_name = stream_name
-        self.__profile_name = profile_name
+        self.stream_name = stream_name
+        self.profile_name = profile_name    
+        self.stream_buffer = []
 
-    def connect(self):                
-        session = boto3.Session(profile_name=self.__profile_name)
+        session = boto3.Session(profile_name=self.profile_name)
         self.client = session.client('kinesis')
-        self.stream = self.client.describe_stream(StreamName=self.__stream_name)
+        self.stream = self.client.describe_stream(StreamName=self.stream_name)
         if self.stream and 'StreamDescription' in self.stream:
             self.stream = self.stream['StreamDescription']
             i=0    
@@ -210,23 +210,19 @@ class KinesisStreamConsumer():
                 self.stream['Shards'][i]['ShardIterator'] = shard_iterator['ShardIterator']
         if self.stream['StreamStatus'] != 'ACTIVE':
             raise Exception('Stream status %s' % (self.stream['StreamStatus']))
-        
-        return self.stream
-
-    def loop(self):                
-        while True:        
-            for i in range(len(self.stream['Shards'])):
-                response = self.client.get_records(\
-                    ShardIterator = self.stream['Shards'][i]['ShardIterator'],\
-                    Limit = 100)
-                self.stream['Shards'][i]['ShardIterator'] = response['NextShardIterator']
-                if len(response['Records'])> 0:
-                    for r in response['Records']:
-                        try:
-                            rec = r['Data'].decode(encoding="UTF-8", errors="strict")                        
-                            #rec = json.loads(rec.replace("\'", "\""))                            
-                            print(rec)
-                        except Exception as e:
-                            print('Invalid record:'+str(e))
-            time.sleep(1)
+                
+    def consume(self):
+        for i in range(len(self.stream['Shards'])):
+            response = self.client.get_records(\
+                ShardIterator = self.stream['Shards'][i]['ShardIterator'],\
+                Limit = 100)
+            self.stream['Shards'][i]['ShardIterator'] = response['NextShardIterator']
+            if len(response['Records'])> 0:
+                for r in response['Records']:
+                    try:
+                        rec = r['Data'].decode(encoding="UTF-8", errors="strict") 
+                        self.stream_buffer.append(rec)
+                    except Exception as e:
+                        print('Invalid record:'+str(e))
+            
      
\ No newline at end of file
