@@ -188,7 +188,7 @@ class SharedDataFrame:
                         (self.database,self.feeder,self.period,self.tagstr,100,time.time()-tini))                
         return pd.DataFrame([])
 
-    def Write(self,startDate=[]):
+    def Write(self):
         tini = time.time()
         Logger.log.debug('Writing %s/%s/%s/%s  ...%.2f%% ' % \
             (self.database,self.feeder,self.period,self.tagstr,0.0))        
@@ -203,9 +203,10 @@ class SharedDataFrame:
                 'columns': self.data.columns.values.tolist()                                 
                 }
             json.dump(shm_info, outfile, indent=3)
-            if self.sharedData.s3write:
-                S3Upload(jsonpath)
-        
+
+        if self.sharedData.s3write:
+            S3Upload(jsonpath)
+
         np.save(str(npypath),self.data.values.astype(np.float64))
         if self.sharedData.s3write:
             S3Upload(npypath)
